.. image:: https://img.shields.io/pypi/v/pmxbot.nsfw.svg
   :target: https://pypi.org/project/pmxbot.nsfw

.. image:: https://img.shields.io/pypi/pyversions/pmxbot.nsfw.svg

.. image:: https://img.shields.io/pypi/dm/pmxbot.nsfw.svg

.. image:: https://img.shields.io/travis/jaraco/pmxbot.nsfw/master.svg
   :target: http://travis-ci.org/jaraco/pmxbot.nsfw


Config
------

Add "exclude patterns" to your config to cause messages matching
any of those patterns to be suppressed::

    exclude patterns:
      - testicle
